<?php

namespace App\Http\Controllers\Api\Customer;


use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;

class LoginController extends Controller
{


    public function __construct()
    {
        $this->middleware('customer:api', ['except' => ['loginCustomer']]);
    }


    public function loginCustomer(Request $request)
    {
        $validator = Validator::make(request()->all(), [
            'email' => 'required|email',
            "password" => "required",
        ]);
        if ($validator->fails()) {
            return response()->json(array('error' => true, 'validation_error' => true, 'message' => $validator->errors()));
        }

        if ($token = auth('customer-api')->attempt(['email' => $request->email, 'password' => $request->password])) {

            return $this->respondWithToken($token);

        }
        return response()->json(['error' => 'Unauthorized'], 401);
    }


    protected function respondWithToken($token)
    {
        return response()->json([
            'user' => auth('customer-api')->user(),
            'access_token' => $token,
            'token_type' => 'bearer',
            'expires_in' => auth('customer-api')->factory()->getTTL() * 10000
        ]);
    }


}
