<?php

namespace App\Http\Controllers\Api;

use App\Address;
use App\Customer;
use App\Mail\CustomerCreated;
use App\Order;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;

class OrdersController extends Controller
{
    public function guestStore(Request $request)
    {

        try {

            $user = $request->user;
            $cart = $request->cart;
            $address = $request->address;

            if (Customer::where('email', $user['email'])->get()->count()) {
                return response()->json(array('error' => true, 'message' => 'user with this email already exist'));
            }


            $customer = new Customer();
            $customer->name = $user['name'];
            $customer->email = $user['email'];
            $customer->phone = $user['phone'];
            $password = Str::random(8);
            $customer->password = $password;
            $customer->save();


            $addr = new Address();
            $addr->customer_id = $customer->id;
            $addr->title = $address['title'];
            $addr->detail = $address['detail'];
            $addr->lng = $address['lng'];
            $addr->lat = $address['lat'];
            $addr->save();

            $order = new Order();


            $order->customer_id = $customer->id;


            $order->restaurant_id = $cart['restaurant_id'];
            $order->phone = $customer->phone;
            $order->payment_method = $request->order_detail['payment_method'];
            $order->order_time = $request->order_detail['order_time'];
            $order->status = 'pending';
            $order->lng = $addr->lng;
            $order->lat = $addr->lat;
            $order->address_id = $addr->id;
            $order->payable_amount = $cart['cart_amount']['payable'];
            $order->note = $user['additional_notes'];
            $order->save();
            $order->storeOrderNo();
            $order->newOrderNotification();

            Mail::to($customer->email)->send(new CustomerCreated($customer, $password));
//        try {
//
//        } catch (\Exception $exception) {
//            $customer->delete();
//            return response()->json(array('error' => true, 'message' => $exception->getMessage()));
//        }


            return response()->json(array('customer' => array('id' => $customer->id, 'name' => $customer->name), 'error' => false, 'message' => false));


        } catch (\Exception $exception) {
            return response()->json(array('error' => true, 'message' => $exception->getMessage()));
        }

    }


    public function store(Request $request)
    {

        try {

            $order = new Order();

            $customer = $request->user;

            $order->customer_id = $customer['id'];
            $cart = $request->cart;

            $order->restaurant_id = $cart['restaurant_id'];
            $order->phone = $customer['phone'];
            $order->payment_method = $request->order_detail['payment_method'];
            $order->order_time = $request->order_detail['order_time'];
            $order->status = 'pending';
            $order->lng = $customer['selected_address']['lng'];
            $order->lat = $customer['selected_address']['lat'];
            $order->address_id = $customer['selected_address']['id'];
            $order->payable_amount = $cart['cart_amount']['payable'];
            $order->note = $customer['additional_notes'];

            $order->save();
            $order->storeOrderNo();
            $order->storeItems($cart['food_list']);
            $order->newOrderNotification();
            return response()->json(array('customer' => array('error' => false, 'message' => 'order stored successfully')));

        } catch (\Exception $exception) {
            return error_response($exception);
        }

    }


    public function storeOrder(Request $request)
    {


        try {
            $newUser = false;
            $password = '';
            $user = $request->user;
            $cart = $request->cart;
            if (!$user['id']) {
                $validator = Validator::make($user, [
                    'email' => 'required|email|unique:customers',
                    'name' => 'required',
                    "phone" => 'required',
                ]);
                if ($validator->fails()) {
                    return response()->json(array('error' => true, 'validation_error' => true, 'message' => $validator->errors()));
                }
                $customer = new Customer();
                $customer->name = $user['name'];
                $customer->email = $user['email'];
                $customer->phone = $user['phone'];
                $password = Str::random(8);
                $customer->password = $password;
                $customer->save();
                $user_id = $customer->id;
                $newUser = true;
            } else {
                $user_id = $user['id'];
            }


            $address = Address::create(array_merge($request->address, ['customer_id' => $user_id]));

            $order = Order::create(array_merge($request->order, ['address_id' => $address->id, 'customer_id' => $user_id]));
            $order->storeOrderNo();
            $order->storeItems($cart['food_list']);
            if ($newUser)
                Mail::to($customer->email)->send(new CustomerCreated($customer, $password));


            $order->newOrderNotification();
            return response()->json(array('customer' => array('error' => false, 'message' => 'order stored successfully')));
        } catch (\Exception $exception) {
            return error_response($exception);
        }

    }


    function getOrders(Request $request)
    {


        try {
            $customer = Customer::find($request->user_id);
            $current_orders = $customer->orders()->current()->get();
            $past_orders = $customer->orders()->past()->paginate(10);
            $pagination = prospiral_paginate($past_orders);
            $orders = array('current' => array('data' => \App\Http\Resources\Order::collection($current_orders)), 'past' => array('data' => \App\Http\Resources\Order::collection($past_orders), 'pagination' => $pagination));

            return response()->json(array('orders' => $orders, 'error' => false, 'message' => 'orders fetched successfully'));

        } catch (\Exception $exception) {
            return response()->json(array('error' => true, 'message' => $exception->getMessage()));
        }
    }


}
