<?php

namespace App\Http\Controllers;

use App\Cuisine;
use App\RestaurantTheme;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;

class RestaurantThemeController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if (request()->ajax()) {
            return DataTables::of(RestaurantTheme::select('id', 'title')->orderBy('id', 'desc')->get())->addColumn('action', function ($theme) {
                $edit_route = route('restaurant-theme.edit', ['restaurantTheme' => $theme->id]);
                $delete_route = route('restaurant-theme.destroy', ['restaurant_theme' => $theme->id]);
                $del_func = "onclick = deletenow('$delete_route')";
                return "<a type='button' href='$edit_route' class='btn btn-info btn-circle btn-sm' title='edit restaurant'><i class='fas fa-edit'></i></a> <a type='button' href='#'  $del_func  class='btn btn-danger btn-circle btn-sm  delete-btn' data-route='$delete_route'  title='delete restaurant'><i class='far fa-trash-alt'></i></a>";
            })->rawColumns(['action'])
                ->make(true);

        }
        return view('admin.restaurant_theme.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $cuisines = Cuisine::all();
        return view('admin.restaurant_theme.create', compact('cuisines'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $image = prospiral_store_file($request->image, 'images/restaurant_themes');
        $title = $request->title;
        RestaurantTheme::create(array(
            'image' => $image,
            'title' => $title
        ))->cuisines()->attach($request->cuisines);
        flash('Restaurant Group Created Successfully');
        return redirect()->back();

    }

    /**
     * Display the specified resource.
     *
     * @param \App\RestaurantTheme $restaurantTheme
     * @return \Illuminate\Http\Response
     */
    public function show(RestaurantTheme $restaurantTheme)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param \App\RestaurantTheme $restaurantTheme
     * @return \Illuminate\Http\Response
     */
    public function edit(RestaurantTheme $restaurantTheme)
    {
        $cuisines = Cuisine::all();
        return view('admin.restaurant_theme.edit', compact('restaurantTheme', 'cuisines'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param \App\RestaurantTheme $restaurantTheme
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, RestaurantTheme $restaurantTheme)
    {
        $image = $request->hasFile('image') ? prospiral_store_file($request->image, 'images/restaurant_themes') : $restaurantTheme->image;

        $title = $request->title;
        $restaurantTheme->update(array(
            'image' => $image,
            'title' => $title
        ));
        $restaurantTheme->cuisines()->detach();
        $restaurantTheme->cuisines()->attach($request->cuisines);
        flash('Restaurant Group Updated Successfully');
        return redirect()->back();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param \App\RestaurantTheme $restaurantTheme
     * @return \Illuminate\Http\Response
     */
    public function destroy(RestaurantTheme $restaurantTheme)
    {

        $restaurantTheme->delete();
        flash('Group Delete Successfully')->warning();
        return redirect()->back();
    }
}
