<?php

namespace App;

use Carbon\Carbon;
use http\Env\Request;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Restaurant extends Model
{

    protected $fillable = ['name', 'sunday_opening', 'monday_opening', 'tuesday_opening',
        'wednesday_opening', 'thursday_opening', 'friday_opening', 'saturday_opening',
        'sunday_closing', 'monday_closing', 'tuesday_closing', 'wednesday_closing',
        'thursday_closing', 'friday_closing', 'saturday_closing', 'avg_cost', 'alchohal',
        'wifi', 'outdoor_seating', 'kids_friendly', 'parking_area',
        'premium', 'featured', 'dine_in', 'delivery', 'online_payment',
        'cash_on_delivery', 'take_away', 'online', 'active', 'min_order_amount', 'phone', 'address',
        'image', 'header_image', 'description', 'city_id', 'lat', 'lng'
    ];


    public function foodSections()
    {
        return $this->hasMany(foodSection::class, 'restaurant_id');
    }


    public function stringifyCuisine()
    {
        $cuisines = "";
        foreach ($this->cuisines as $index => $cuisine) {
            $cuisines .= $cuisine->name;
            if (++$index != $this->cuisines()->count())
                $cuisines .= ", ";

        }
        return $cuisines;

    }


    public function stringifyCategories()
    {
        $classes = "";
        foreach ($this->categories as $index => $class) {
            $classes .= $class->name;
            if (++$index != $this->categories()->count())
                $classes .= ", ";

        }
        return $classes;

    }


    public function stringifyFacilities()
    {


        $facilities = [];
        $facilities[] = array('title' => 'alcohol', 'status' => $this->alcohol == true);
        $facilities[] = array('title' => 'wifi', 'status' => $this->wifi == true);
        $facilities[] = array('title' => 'outdoor_seating', 'status' => $this->outdoor_seating == true);
        $facilities[] = array('title' => 'kids friendly', 'status' => $this->kids_friendly == true);
        $facilities[] = array('title' => 'parking area', 'status' => $this->parking_area == true);
        $facilities[] = array('title' => 'premium', 'status' => $this->premium == true);
        $facilities[] = array('title' => 'featured', 'status' => $this->alcohol == true);
        $facilities[] = array('title' => 'dine in', 'status' => $this->dine_in == true);
        $facilities[] = array('title' => 'delivery', 'status' => $this->delivery == true);
        $facilities[] = array('title' => 'online payment', 'status' => $this->online_payment == true);
        $facilities[] = array('title' => 'cash on delivery', 'status' => $this->cash_on_delivery == true);
        $facilities[] = array('title' => 'take away', 'status' => $this->take_away == true);
        $facilities[] = array('title' => 'online', 'status' => $this->online == true);
        $facilities[] = array('title' => 'table booking', 'status' => $this->table_booking == true);
        return $facilities;

    }


    public function getTimings($value = '')
    {

        $weekMap = [
            0 => 'sunday',
            1 => 'monday',
            2 => 'tuesday',
            3 => 'wednesday',
            4 => 'thursday',
            5 => 'friday',
            6 => 'saturday',
        ];

        $timings = [];

        array_push($timings, array('day' => "Today",
            'opening' => $this->{$weekMap[Carbon::today('Asia/Dubai')->dayOfWeek] . "_opening"},
            'closing' => $this->{$weekMap[Carbon::today('Asia/Dubai')->dayOfWeek] . "_closing"},

        ));
        foreach ($weekMap as $key => $day) {

            array_push($timings, array('day' => $day,
                'opening' => $this->{$day . "_opening"},
                'closing' => $this->{$day . "_closing"},

            ));
        }


        return $timings;

    }


    public function getOpeningTime($value = 0)
    {


        $day = strtolower(Carbon::today('Asia/Dubai')->addDay($value)->format('l')) . "_opening";


        return Carbon::parse($this->$day)->addDay($value);

    }


    public function getClosingTime($value = 0)
    {

        $day = strtolower(Carbon::today('Asia/Dubai')->addDay($value)->format('l')) . "_closing";
        $now = Carbon::parse($this->$day)->addDay($value);


        if ($now->gte(Carbon::parse('12:00 AM')))
            $now->addDay(1);

        return $now;


    }


    public function getLaterTimings()
    {

        $opening_time = Carbon::parse($this->getOpeningTime()->addMinutes(40));
        $now = Carbon::now()->addHours(5);
        $now = $now->subMinutes(((int)$now->format('i') % 5));
        $thisday = Carbon::today('Asia/Dubai');


        if ($opening_time->gte($now)) {


            $now = $opening_time;

        }


        $today = new \stdClass();

        $today->day = str_limit($thisday->format('l'), 3, '');
        $today->date = $thisday->format('d');
        $today->timings = [];

        $tomorrow = new \stdClass();

        $tomorrow->day = str_limit($thisday->addDay(1)->format('l'), 3, '');
        $tomorrow->date = $thisday->format('d');
        $tomorrow->timings = [];
        $daTomorrow = new \stdClass();

        $daTomorrow->day = str_limit($thisday->addDay(1)->format('l'), 3, '');
        $daTomorrow->date = $thisday->format('d');
        $daTomorrow->timings = [];


        while ($now->lte($this->getClosingTime())) {


            $now = $now->addMinutes(15);
            $today->timings[] = $now->format('g:i A');

        }
        if (count($today->timings))
            array_pop($today->timings);


        $tmw = Carbon::parse($this->getOpeningTime(1)->addHours(1));

        while ($tmw->lte($this->getClosingTime(1))) {


            $tmw = $tmw->addMinutes(15);
            $tomorrow->timings[] = $tmw->format('g:i A');

        }
        if (count($tomorrow->timings))
            array_pop($tomorrow->timings);


        $dtmw = Carbon::parse($this->getOpeningTime(2)->addHours(1));

        while ($dtmw->lte($this->getClosingTime(2))) {


            $dtmw = $dtmw->addMinutes(15);
            $daTomorrow->timings[] = $dtmw->format('g:i A');

        }
        if (count($daTomorrow->timings))
            array_pop($daTomorrow->timings);


        $timings = new \stdClass();
        $timings->today = $today;
        $timings->tomorrow = $tomorrow;
        $timings->daTomorrow = $daTomorrow;

        return $timings;

    }


    public function store_acronym()
    {

        $words = explode(" ", $this->name);
        $acronym = "";

        foreach ($words as $w) {
            $acronym .= $w[0];
        }
        $acronym .= "-" . $this->id;

        $this->acronym = strtoupper($acronym);
        $this->slug = $this->id . "-" . str_slug($this->name, "-");
        $this->save();


    }


    //
    public function scopeActive($query)
    {
        return $query->where('active', 1);

    }


    public static function scopeGetByDistance($query, $lat, $lng, $distance)
    {
        $results = DB::select(DB::raw('SELECT id, ( 3959 * acos( cos( radians(' . $lat . ') ) * cos( radians( lat ) ) * cos( radians( lng ) - radians(' . $lng . ') ) + sin( radians(' . $lat . ') ) * sin( radians(lat) ) ) ) AS distance FROM restaurants HAVING distance < ' . $distance . ' ORDER BY distance'));

        if (!empty($results)) {

            $ids = [];

            //Extract the id's
            foreach ($results as $q) {
                array_push($ids, $q->id);
            }

            return $query->whereIn('id', $ids);

        }

        return $query->where('id', 0);

    }

    function measureDistance($lat, $lng, $earthRadius = 6371000)
    {
        // convert from degrees to radians
        $latFrom = deg2rad($lat);
        $lonFrom = deg2rad($lng);
        $latTo = deg2rad($this->lat);
        $lonTo = deg2rad($this->lng);

        $latDelta = $latTo - $latFrom;
        $lonDelta = $lonTo - $lonFrom;

        $angle = 2 * asin(sqrt(pow(sin($latDelta / 2), 2) +
                cos($latFrom) * cos($latTo) * pow(sin($lonDelta / 2), 2)));
        return ($angle * $earthRadius) / 1000;
    }


    public
    function scopeFilterCuisines($query, $cuisines)
    {

        if (!count($cuisines))
            return $query;

        return $query->whereHas('cuisines', function ($query) use ($cuisines) {
            $query->whereIn('cuisines.id', $cuisines);
        });

    }


    public
    function scopeFilterCategories($query, $categories)
    {

        if (!count($categories))
            return $query;

        return $query->whereHas('categories', function ($query) use ($categories) {
            $query->whereIn('rest_categories.id', $categories);
        });

    }


//    relationships methods
    public function cuisines()
    {
        return $this->belongsToMany(Cuisine::class, 'cuisine_restaurant', 'restaurant_id', 'cuisine_id');
    }

    public function categories()
    {
        return $this->belongsToMany(RestCategory::class, 'categories_restaurants', 'restaurant_id', 'class_id');
    }

    public
    function foodItems()
    {
        return $this->hasMany(FoodItem::class, 'restaurant_id');
    }

    public
    function orders()
    {
        return $this->hasMany(Order::class, 'restaurant_id');
    }

    public
    function merchant()
    {
        return $this->hasOne(User::class, 'restaurant_id');
    }


}
